@@ -3,5 +3,8 @@
     subclasses. It will delete old files when a new file is being save and it
     will delete files on model instance deletion.
 '''
-__version__ = '5.2.0'
-default_app_config = 'django_cleanup.apps.CleanupConfig'
+import django
+
+__version__ = '6.0.0'
+if django.VERSION < (3, 2):
+    default_app_config = 'django_cleanup.apps.CleanupConfig'
